@@ -1,7 +1,6 @@
 """Supporting functions for polydata and grid objects."""
 
 import collections.abc
-import ctypes
 import enum
 import logging
 import signal
@@ -122,7 +121,7 @@ def convert_array(arr, name=None, deep=0, array_type=None):
         return vtk_data
     # Otherwise input must be a vtkDataArray
     if not isinstance(arr, (vtk.vtkDataArray, vtk.vtkBitArray, vtk.vtkStringArray)):
-        raise TypeError('Invalid input array type ({}).'.format(type(arr)))
+        raise TypeError(f'Invalid input array type ({type(arr)}).')
     # Handle booleans
     if isinstance(arr, vtk.vtkBitArray):
         arr = vtk_bit_array_to_char(arr)
@@ -144,45 +143,18 @@ def point_array(mesh, name):
     return convert_array(vtkarr)
 
 
-def point_scalar(mesh, name):
-    """Return point array of a vtk object.
-
-    DEPRECATED: please use `point_array` instead.
-    """
-    warnings.warn("DEPRECATED: please use `point_array` instead.")
-    return point_array(mesh, name)
-
-
 def field_array(mesh, name):
     """Return field array of a vtk object."""
     vtkarr = mesh.GetFieldData().GetAbstractArray(name)
     return convert_array(vtkarr)
 
 
-def field_scalar(mesh, name):
-    """Return field array of a vtk object.
-
-    DEPRECATED: please use `field_array` instead.
-    """
-    warnings.warn("DEPRECATED: please use `field_array` instead.")
-    return field_array(mesh, name)
-
-
 def cell_array(mesh, name):
     """Return cell array of a vtk object."""
     vtkarr = mesh.GetCellData().GetAbstractArray(name)
     return convert_array(vtkarr)
 
 
-def cell_scalar(mesh, name):
-    """Return cell array of a vtk object.
-
-    DEPRECATED: please use `cell_array` instead.
-    """
-    warnings.warn("DEPRECATED: please use `cell_array` instead.")
-    return cell_array(mesh, name)
-
-
 def row_array(data_object, name):
     """Return row array of a vtk object."""
     vtkarr = data_object.GetRowData().GetAbstractArray(name)
@@ -202,11 +174,11 @@ def parse_field_choice(field):
         elif field in ['row', 'r',]:
             field = FieldAssociation.ROW
         else:
-            raise ValueError('Data field ({}) not supported.'.format(field))
+            raise ValueError(f'Data field ({field}) not supported.')
     elif isinstance(field, FieldAssociation):
         pass
     else:
-        raise ValueError('Data field ({}) not supported.'.format(field))
+        raise ValueError(f'Data field ({field}) not supported.')
     return field
 
 
@@ -233,7 +205,7 @@ def get_array(mesh, name, preference='cell', info=False, err=False):
     if isinstance(mesh, vtk.vtkTable):
         arr = row_array(mesh, name)
         if arr is None and err:
-            raise KeyError('Data array ({}) not present in this dataset.'.format(name))
+            raise KeyError(f'Data array ({name}) not present in this dataset.')
         field = FieldAssociation.ROW
         if info:
             return arr, field
@@ -260,7 +232,7 @@ def get_array(mesh, name, preference='cell', info=False, err=False):
             else:
                 return farr
         else:
-            raise ValueError('Data field ({}) not supported.'.format(preference))
+            raise ValueError(f'Data field ({preference}) not supported.')
     arr = None
     field = None
     if parr is not None:
@@ -273,7 +245,7 @@ def get_array(mesh, name, preference='cell', info=False, err=False):
         arr = farr
         field = FieldAssociation.NONE
     elif err:
-        raise KeyError('Data array ({}) not present in this dataset.'.format(name))
+        raise KeyError(f'Data array ({name}) not present in this dataset.')
     if info:
         return arr, field
     return arr
@@ -434,12 +406,80 @@ def is_meshio_mesh(mesh):
         return False
 
 
-def wrap(vtkdataset):
+def wrap(dataset):
     """Wrap any given VTK data object to its appropriate PyVista data object.
 
     Other formats that are supported include:
     * 2D :class:`numpy.ndarray` of XYZ vertices
     * 3D :class:`numpy.ndarray` representing a volume. Values will be scalars.
+    * 3d :class:`trimesh.Trimesh` mesh.
+
+    Parameters
+    ----------
+    dataset : :class:`numpy.ndarray`, :class:`trimesh.Trimesh`, or VTK object
+        Dataset to wrap.
+
+    Returns
+    -------
+    wrapped_dataset : pyvista class
+        The `pyvista` wrapped dataset.
+
+    Examples
+    --------
+    Wrap a numpy array representing a random point cloud
+
+    >>> import numpy as np
+    >>> import pyvista
+    >>> points = np.random.random((10, 3))
+    >>> cloud = pyvista.wrap(points)
+    >>> cloud  # doctest:+SKIP
+    PolyData (0x7fc52db83d70)
+      N Cells:  10
+      N Points: 10
+      X Bounds: 1.123e-01, 7.457e-01
+      Y Bounds: 1.009e-01, 9.877e-01
+      Z Bounds: 2.346e-03, 9.640e-01
+      N Arrays: 0
+
+    Wrap a Trimesh object
+
+    >>> import trimesh
+    >>> import pyvista
+    >>> points = [[0, 0, 0], [0, 0, 1], [0, 1, 0]]
+    >>> faces = [[0, 1, 2]]
+    >>> tmesh = trimesh.Trimesh(points, faces=faces, process=False)
+    >>> mesh = pyvista.wrap(tmesh)
+    >>> mesh  # doctest:+SKIP
+    PolyData (0x7fc55ff27ad0)
+      N Cells:  1
+      N Points: 3
+      X Bounds: 0.000e+00, 0.000e+00
+      Y Bounds: 0.000e+00, 1.000e+00
+      Z Bounds: 0.000e+00, 1.000e+00
+      N Arrays: 0
+
+    Wrap a VTK object
+
+    >>> import pyvista
+    >>> import vtk
+    >>> points = vtk.vtkPoints()
+    >>> p = [1.0, 2.0, 3.0]
+    >>> vertices = vtk.vtkCellArray()
+    >>> pid = points.InsertNextPoint(p)
+    >>> _ = vertices.InsertNextCell(1)
+    >>> _ = vertices.InsertCellPoint(pid)
+    >>> point = vtk.vtkPolyData()
+    >>> _ = point.SetPoints(points)
+    >>> _ = point.SetVerts(vertices)
+    >>> mesh = pyvista.wrap(point)
+    >>> mesh  # doctest:+SKIP
+    PolyData (0x7fc55ff27ad0)
+      N Cells:  1
+      N Points: 3
+      X Bounds: 0.000e+00, 0.000e+00
+      Y Bounds: 0.000e+00, 1.000e+00
+      Z Bounds: 0.000e+00, 1.000e+00
+      N Arrays: 0
 
     """
     wrappers = {
@@ -454,32 +494,39 @@ def wrap(vtkdataset):
         # 'vtkParametricSpline': pyvista.Spline,
     }
     # Otherwise, we assume a VTK data object was passed
-    if hasattr(vtkdataset, 'GetClassName'):
-        key = vtkdataset.GetClassName()
-    elif vtkdataset is None:
+    if hasattr(dataset, 'GetClassName'):
+        key = dataset.GetClassName()
+    elif dataset is None:
         return None
-    elif isinstance(vtkdataset, np.ndarray):
-        if vtkdataset.ndim == 1 and vtkdataset.shape[0] == 3:
-            return pyvista.PolyData(vtkdataset)
-        if vtkdataset.ndim > 1 and vtkdataset.ndim < 3 and vtkdataset.shape[1] == 3:
-            return pyvista.PolyData(vtkdataset)
-        elif vtkdataset.ndim == 3:
-            mesh = pyvista.UniformGrid(vtkdataset.shape)
-            mesh['values'] = vtkdataset.ravel(order='F')
+    elif isinstance(dataset, np.ndarray):
+        if dataset.ndim == 1 and dataset.shape[0] == 3:
+            return pyvista.PolyData(dataset)
+        if dataset.ndim > 1 and dataset.ndim < 3 and dataset.shape[1] == 3:
+            return pyvista.PolyData(dataset)
+        elif dataset.ndim == 3:
+            mesh = pyvista.UniformGrid(dataset.shape)
+            mesh['values'] = dataset.ravel(order='F')
             mesh.active_scalars_name = 'values'
             return mesh
         else:
-            print(vtkdataset.shape, vtkdataset)
+            print(dataset.shape, dataset)
             raise NotImplementedError('NumPy array could not be converted to PyVista.')
-    elif is_meshio_mesh(vtkdataset):
-        return from_meshio(vtkdataset)
+    elif is_meshio_mesh(dataset):
+        return from_meshio(dataset)
+    elif dataset.__class__.__name__ == 'Trimesh':
+        # trimesh doesn't pad faces
+        n_face = dataset.faces.shape[0]
+        faces = np.empty((n_face, 4), dataset.faces.dtype)
+        faces[:, 1:] = dataset.faces
+        faces[:, 0] = 3
+        return pyvista.PolyData(np.asarray(dataset.vertices), faces)
     else:
-        raise NotImplementedError('Type ({}) not able to be wrapped into a PyVista mesh.'.format(type(vtkdataset)))
+        raise NotImplementedError(f'Type ({type(dataset)}) not able to be wrapped into a PyVista mesh.')
     try:
-        wrapped = wrappers[key](vtkdataset)
+        wrapped = wrappers[key](dataset)
     except KeyError:
-        logging.warning('VTK data type ({}) is not currently supported by pyvista.'.format(key))
-        return vtkdataset # if not supported just passes the VTK data object
+        logging.warning(f'VTK data type ({key}) is not currently supported by pyvista.')
+        return dataset  # if not supported just passes the VTK data object
     return wrapped
 
 
@@ -490,8 +537,6 @@ def image_to_texture(image):
 
 def numpy_to_texture(image):
     """Convert a NumPy image array to a vtk.vtkTexture."""
-    if not isinstance(image, np.ndarray):
-        raise TypeError('Unknown input type ({})'.format(type(image)))
     return pyvista.Texture(image)
 
 
@@ -510,7 +555,7 @@ def is_inside_bounds(point, bounds):
         bounds = collections.deque(bounds)
         return is_inside_bounds(point, bounds)
     if not isinstance(point, collections.deque):
-        raise TypeError('Unknown input data type ({}).'.format(type(point)))
+        raise TypeError(f'Unknown input data type ({type(point)}).')
     if len(point) < 1:
         return True
     p = point.popleft()
@@ -545,14 +590,10 @@ def fit_plane_to_points(points, return_meta=False):
 def raise_not_matching(scalars, mesh):
     """Raise exception about inconsistencies."""
     if isinstance(mesh, vtk.vtkTable):
-        raise ValueError('Number of scalars ({})'.format(scalars.size) +
-                         'must match number of rows ' +
-                         '({}).'.format(mesh.n_rows) )
-    raise ValueError('Number of scalars ({}) '.format(scalars.size) +
-                     'must match either the number of points ' +
-                     '({}) '.format(mesh.n_points) +
-                     'or the number of cells ' +
-                     '({}). '.format(mesh.n_cells) )
+        raise ValueError(f'Number of scalars ({scalars.size}) must match number of rows ({mesh.n_rows}).')
+    raise ValueError(f'Number of scalars ({scalars.size}) ' +
+                     f'must match either the number of points ({mesh.n_points}) ' +
+                     f'or the number of cells ({mesh.n_cells}).')
 
 
 def generate_plane(normal, origin):
@@ -565,22 +606,6 @@ def generate_plane(normal, origin):
     return plane
 
 
-def generate_report(additional=None, ncol=3, text_width=54, sort=False):
-    """Generate a report.
-
-    DEPRECATED: Please use :class:`pyvista.Report` instead.
-
-    """
-    logging.warning('DEPRECATED: Please use `pyvista.Report` instead.')
-    core = ['pyvista', 'vtk', 'numpy', 'imageio', 'appdirs', 'scooby']
-    optional = ['matplotlib', 'PyQt5', 'IPython', 'colorcet',
-                'cmocean']
-    report = scooby.Report(core=core, optional=optional,
-                           additional=additional, ncol=ncol,
-                           text_width=text_width, sort=sort)
-    return report
-
-
 def try_callback(func, *args):
     """Wrap a given callback in a try statement."""
     try:
@@ -729,8 +754,41 @@ def abstract_class(cls_):
 
     def __new__(cls, *args, **kwargs):
         if cls is cls_:
-            raise TypeError('{} is an abstract class and may not be instantiated.'
-                            .format(cls.__name__))
+            raise TypeError(f'{cls.__name__} is an abstract class and may not be instantiated.')
         return object.__new__(cls)
     cls_.__new__ = __new__
     return cls_
+
+
+def axis_rotation(points, angle, inplace=False, deg=True, axis='z'):
+    """Rotate points angle (in deg) about an axis."""
+    axis = axis.lower()
+
+    # Copy original array to if not inplace
+    if not inplace:
+        points = points.copy()
+
+    # Convert angle to radians
+    if deg:
+        angle *= np.pi / 180
+
+    if axis == 'x':
+        y = points[:, 1] * np.cos(angle) - points[:, 2] * np.sin(angle)
+        z = points[:, 1] * np.sin(angle) + points[:, 2] * np.cos(angle)
+        points[:, 1] = y
+        points[:, 2] = z
+    elif axis == 'y':
+        x = points[:, 0] * np.cos(angle) + points[:, 2] * np.sin(angle)
+        z = - points[:, 0] * np.sin(angle) + points[:, 2] * np.cos(angle)
+        points[:, 0] = x
+        points[:, 2] = z
+    elif axis == 'z':
+        x = points[:, 0] * np.cos(angle) - points[:, 1] * np.sin(angle)
+        y = points[:, 0] * np.sin(angle) + points[:, 1] * np.cos(angle)
+        points[:, 0] = x
+        points[:, 1] = y
+    else:
+        raise ValueError('invalid axis. Must be either "x", "y", or "z"')
+
+    if not inplace:
+        return points
